[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Qemu-devel] [PATCH v5 06/16] gdbstub: add multiprocess support to 'sC'
From: |
Luc Michel |
Subject: |
[Qemu-devel] [PATCH v5 06/16] gdbstub: add multiprocess support to 'sC' packets |
Date: |
Sat, 10 Nov 2018 09:11:37 +0100 |
Change the sC packet handling to support the multiprocess extension.
Instead of returning the first thread, we return the first thread of the
current process.
Signed-off-by: Luc Michel <address@hidden>
Reviewed-by: Philippe Mathieu-Daudé <address@hidden>
Reviewed-by: Alistair Francis <address@hidden>
---
gdbstub.c | 11 ++++++++---
1 file changed, 8 insertions(+), 3 deletions(-)
diff --git a/gdbstub.c b/gdbstub.c
index ba8b1a3413..9be83486f5 100644
--- a/gdbstub.c
+++ b/gdbstub.c
@@ -1546,13 +1546,18 @@ static int gdb_handle_packet(GDBState *s, const char
*line_buf)
type = strtoul(p, (char **)&p, 16);
sstep_flags = type;
put_packet(s, "OK");
break;
} else if (strcmp(p,"C") == 0) {
- /* "Current thread" remains vague in the spec, so always return
- * the first CPU (gdb returns the first thread). */
- put_packet(s, "QC1");
+ /* "Current thread" remains vague in the spec, so always return the
+ * first thread of the current process (gdb returns the first
+ * thread).
+ */
+ cpu = get_first_cpu_in_process(s, gdb_get_cpu_process(s,
s->g_cpu));
+ snprintf(buf, sizeof(buf), "QC%s",
+ gdb_fmt_thread_id(s, cpu, thread_id, sizeof(thread_id)));
+ put_packet(s, buf);
break;
} else if (strcmp(p,"fThreadInfo") == 0) {
s->query_cpu = first_cpu;
goto report_cpuinfo;
} else if (strcmp(p,"sThreadInfo") == 0) {
--
2.19.1
- [Qemu-devel] [PATCH v5 00/16] gdbstub: support for the multiprocess extension, Luc Michel, 2018/11/10
- [Qemu-devel] [PATCH v5 12/16] gdbstub: add support for vAttach packets, Luc Michel, 2018/11/10
- [Qemu-devel] [PATCH v5 01/16] hw/cpu: introduce CPU clusters, Luc Michel, 2018/11/10
- [Qemu-devel] [PATCH v5 10/16] gdbstub: add multiprocess support to 'D' packets, Luc Michel, 2018/11/10
- [Qemu-devel] [PATCH v5 05/16] gdbstub: add multiprocess support to vCont packets, Luc Michel, 2018/11/10
- [Qemu-devel] [PATCH v5 11/16] gdbstub: add support for extended mode packet, Luc Michel, 2018/11/10
- [Qemu-devel] [PATCH v5 06/16] gdbstub: add multiprocess support to 'sC' packets,
Luc Michel <=
- [Qemu-devel] [PATCH v5 02/16] gdbstub: introduce GDB processes, Luc Michel, 2018/11/10
- [Qemu-devel] [PATCH v5 03/16] gdbstub: add multiprocess support to '?' packets, Luc Michel, 2018/11/10
[Qemu-devel] [PATCH v5 07/16] gdbstub: add multiprocess support to (f|s)ThreadInfo and ThreadExtraInfo, Luc Michel, 2018/11/10